gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r23419 - gnunet/src/testbed


From: gnunet
Subject: [GNUnet-SVN] r23419 - gnunet/src/testbed
Date: Sat, 25 Aug 2012 12:29:17 +0200

Author: harsha
Date: 2012-08-25 12:29:17 +0200 (Sat, 25 Aug 2012)
New Revision: 23419

Modified:
   gnunet/src/testbed/testbed.conf.in
   gnunet/src/testbed/testbed_api.c
   gnunet/src/testbed/testbed_api.h
   gnunet/src/testbed/testbed_api_peers.c
Log:
operation queue renaming

Modified: gnunet/src/testbed/testbed.conf.in
===================================================================
--- gnunet/src/testbed/testbed.conf.in  2012-08-25 00:09:15 UTC (rev 23418)
+++ gnunet/src/testbed/testbed.conf.in  2012-08-25 10:29:17 UTC (rev 23419)
@@ -10,4 +10,5 @@
 UNIXPATH = /tmp/gnunet-service-testbed.sock
 UNIX_MATCH_UID = YES
 UNIX_MATCH_GID = YES
-MAX_PARALLEL_PEER_CREATE = 1000
\ No newline at end of file
+MAX_PARALLEL_OPERATIONS = 1000
+MAX_PARALLEL_SERVICE_CONNECTIONS = 1000

Modified: gnunet/src/testbed/testbed_api.c
===================================================================
--- gnunet/src/testbed/testbed_api.c    2012-08-25 00:09:15 UTC (rev 23418)
+++ gnunet/src/testbed/testbed_api.c    2012-08-25 10:29:17 UTC (rev 23419)
@@ -1159,16 +1159,16 @@
   struct GNUNET_TESTBED_Controller *controller;
   struct GNUNET_TESTBED_InitMessage *msg;
   const char *controller_hostname;
-  unsigned long long max_parallel_peer_create;
+  unsigned long long max_parallel_operations;
 
   if (GNUNET_OK !=
       GNUNET_CONFIGURATION_get_value_number (cfg, "testbed",
-                                             "MAX_PARALLEL_PEER_CREATE",
-                                             &max_parallel_peer_create))
+                                             "MAX_PARALLEL_OPERATIONS",
+                                             &max_parallel_operations))
   {
     GNUNET_break (0);
     return NULL;
-  }                                                          
+  }
   controller = GNUNET_malloc (sizeof (struct GNUNET_TESTBED_Controller));
   controller->cc = cc;
   controller->cc_cls = cc_cls;
@@ -1198,9 +1198,9 @@
   GNUNET_assert (NULL != host);
   GNUNET_TESTBED_mark_host_registered_at_ (host, controller);
   controller->host = host;
-  controller->opq_peer_create =
+  controller->opq_parallel_operations =
     GNUNET_TESTBED_operation_queue_create_ ((unsigned int)
-                                            max_parallel_peer_create);
+                                            max_parallel_operations);
   controller_hostname = GNUNET_TESTBED_host_get_hostname_ (host);
   if (NULL == controller_hostname)
     controller_hostname = "127.0.0.1";
@@ -1279,7 +1279,7 @@
   GNUNET_CONFIGURATION_destroy (controller->cfg);
   if (GNUNET_YES == controller->aux_host)
     GNUNET_TESTBED_host_destroy (controller->host);
-  GNUNET_TESTBED_operation_queue_destroy_ (controller->opq_peer_create);
+  GNUNET_TESTBED_operation_queue_destroy_ 
(controller->opq_parallel_operations);
   GNUNET_free (controller);
 }
 
@@ -1424,7 +1424,8 @@
   msg->operation_id = GNUNET_htonll (opc->id);
   opc->op = GNUNET_TESTBED_operation_create_ (opc, &opstart_link_controllers,
                                               &oprelease_link_controllers);
-  GNUNET_TESTBED_operation_queue_insert_ (master->opq_peer_create, opc->op);
+  GNUNET_TESTBED_operation_queue_insert_ (master->opq_parallel_operations,
+                                          opc->op);
   return opc->op;
 }
 
@@ -1535,7 +1536,7 @@
  */
 struct GNUNET_TESTBED_HelperInit *
 GNUNET_TESTBED_create_helper_init_msg_ (const char *cname,
-                                        const struct 
GNUNET_CONFIGURATION_Handle *cfg)
+                                        const struct 
GNUNET_CONFIGURATION_Handle *cfg)
 {
   struct GNUNET_TESTBED_HelperInit *msg;
   char *config;

Modified: gnunet/src/testbed/testbed_api.h
===================================================================
--- gnunet/src/testbed/testbed_api.h    2012-08-25 00:09:15 UTC (rev 23418)
+++ gnunet/src/testbed/testbed_api.h    2012-08-25 10:29:17 UTC (rev 23419)
@@ -275,9 +275,9 @@
   struct OperationContext *ocq_tail;
 
   /**
    * Operation queue for simultaneous peer creations
    */
-  struct OperationQueue *opq_peer_create;
+  struct OperationQueue *opq_parallel_operations;
 
   /**
    * The operation id counter. use current value and increment

Modified: gnunet/src/testbed/testbed_api_peers.c
===================================================================
--- gnunet/src/testbed/testbed_api_peers.c      2012-08-25 00:09:15 UTC (rev 
23418)
+++ gnunet/src/testbed/testbed_api_peers.c      2012-08-25 10:29:17 UTC (rev 
23419)
@@ -408,7 +408,8 @@
   opc->type = OP_PEER_CREATE;
   opc->op = GNUNET_TESTBED_operation_create_ (opc, &opstart_peer_create,
                                               &oprelease_peer_create);
-  GNUNET_TESTBED_operation_queue_insert_ (controller->opq_peer_create, 
opc->op);
+  GNUNET_TESTBED_operation_queue_insert_ (controller->opq_parallel_operations,
+                                          opc->op);
   return opc->op;
 }
 
@@ -477,7 +478,8 @@
   opc->type = OP_PEER_START;
   opc->op = GNUNET_TESTBED_operation_create_ (opc, &opstart_peer_start,
                                              &oprelease_peer_start);
-  GNUNET_TESTBED_operation_queue_insert_ (opc->c->opq_peer_create, opc->op);
+  GNUNET_TESTBED_operation_queue_insert_ (opc->c->opq_parallel_operations,
+                                          opc->op);
   return opc->op;  
 }
 
@@ -502,7 +504,8 @@
   opc->type = OP_PEER_STOP;
   opc->op = GNUNET_TESTBED_operation_create_ (opc, &opstart_peer_stop,
                                               &oprelease_peer_stop);
-  GNUNET_TESTBED_operation_queue_insert_ (opc->c->opq_peer_create, opc->op);
+  GNUNET_TESTBED_operation_queue_insert_ (opc->c->opq_parallel_operations,
+                                          opc->op);
   return opc->op;
 }
 
@@ -532,7 +535,8 @@
   opc->id = opc->c->operation_counter++;
   opc->op = GNUNET_TESTBED_operation_create_ (opc, &opstart_peer_getinfo,
                                              &oprelease_peer_getinfo);
-  GNUNET_TESTBED_operation_queue_insert_ (opc->c->opq_peer_create, opc->op);
+  GNUNET_TESTBED_operation_queue_insert_ (opc->c->opq_parallel_operations,
+                                          opc->op);
   return opc->op;
 }
 
@@ -576,7 +580,7 @@
   opc->type = OP_PEER_DESTROY;
   opc->op = GNUNET_TESTBED_operation_create_ (opc, &opstart_peer_destroy,
                                               &oprelease_peer_destroy);
-  GNUNET_TESTBED_operation_queue_insert_ (opc->c->opq_peer_create,
+  GNUNET_TESTBED_operation_queue_insert_ (opc->c->opq_parallel_operations,
                                           opc->op);
   return opc->op;
 }
@@ -638,7 +642,7 @@
   opc->type = OP_OVERLAY_CONNECT;
   opc->op = GNUNET_TESTBED_operation_create_ (opc, &opstart_overlay_connect,
                                               &oprelease_overlay_connect);
-  GNUNET_TESTBED_operation_queue_insert_ (opc->c->opq_peer_create,
+  GNUNET_TESTBED_operation_queue_insert_ (opc->c->opq_parallel_operations,
                                           opc->op);
   return opc->op;
 }
@@ -275,9 +275,9 @@
 
   /**
-   * Operation queue for simultaneous peer creations
+   * Operation queue for simultaneous operations
    */




reply via email to

[Prev in Thread] Current Thread [Next in Thread]